import base64
import json
from sendgrid import SendGridAPIClient
from sendgrid.helpers.mail import From, To, Subject, PlainTextContent, HtmlContent, Mail

def send_email_notification(event, context):
    """Triggered from a message on a Pub/Sub topic.
    Args:
         event (dict): Event payload.
         context (google.cloud.functions.Context): Metadata for the event.
    """
    pubsub_message = base64.b64decode(event['data']).decode('utf-8')
    message_json = json.loads(pubsub_message)
    timestamp = message_json['timestamp']
    intendID = message_json['intendID']
    projectName = message_json['projectName']
    artifactName = message_json['artifactName']
    artifactVersion = message_json['artifactVersion']
    environment = message_json['environment']
    requesterEmail = message_json['requesterEmail']
    
    html_text = f"""
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html data-editor-version="2" class="sg-campaigns" xmlns="http://www.w3.org/1999/xhtml">
    <head>
      <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
      <meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1, maximum-scale=1">
      <!--[if !mso]><!-->
      <meta http-equiv="X-UA-Compatible" content="IE=Edge">
      <!--<![endif]-->
      <!--[if (gte mso 9)|(IE)]>
      <xml>
        <o:OfficeDocumentSettings>
          <o:AllowPNG/>
          <o:PixelsPerInch>96</o:PixelsPerInch>
        </o:OfficeDocumentSettings>
      </xml>
      <![endif]-->
      <!--[if (gte mso 9)|(IE)]>
  <style type="text/css">
  </style>
<![endif]-->
      <style type="text/css">
 
  </style>
      <!--user entered Head Start--><!--End Head user entered-->
    </head>
    <body>
      <center class="wrapper" data-link-color="#932A89" data-body-style="font-size:14px; font-family:arial,helvetica,sans-serif; color:#000000; background-color:#f0f0f0;">
        <div class="webkit">
          <table cellpadding="0" cellspacing="0" border="0" width="100%" class="wrapper" bgcolor="#f0f0f0">
            <tr>
              <td valign="top" bgcolor="#f0f0f0" width="100%">
                <table width="100%" role="content-container" class="outer" align="center" cellpadding="0" cellspacing="0" border="0">
                  <tr>
                    <td width="100%">
                      <table width="100%" cellpadding="0" cellspacing="0" border="0">
                        <tr>
                          <td>
                            <!--[if mso]>
    <center>
    <table><tr><td width="620">
  <![endif]-->
                                    <table width="100%" cellpadding="0" cellspacing="0" border="0" style="width:100%; max-width:620px;" align="center">
                                      <tr>
                                        <td role="modules-container" style="padding:0px 10px 0px 10px; color:#000000; text-align:left;" bgcolor="#F0F0F0" width="100%" align="left"><table class="module preheader preheader-hide" role="module" data-type="preheader" border="0" cellpadding="0" cellspacing="0" width="100%" style="display: none !important; mso-hide: all; visibility: hidden; opacity: 0; color: transparent; height: 0; width: 0;">
    <tr>
      <td role="module-content">
        <p></p>
      </td>
    </tr>
  </table><table class="module" role="module" data-type="text" border="0" cellpadding="0" cellspacing="0" width="100%" style="table-layout: fixed;" data-muid="806c535f-a48e-47c3-84e1-e42f460fcd8b" data-mc-module-version="2019-10-22">

  </table><table border="0" cellpadding="0" cellspacing="0" align="center" width="100%" role="module" data-type="columns" style="padding:30px 0px 10px 0px;" bgcolor="#F0F0F0" data-distribution="1,1">
    <tbody>
      <tr role="module-content">
        <td height="100%" valign="top"><table width="300" style="width:300px; border-spacing:0; border-collapse:collapse; margin:0px 0px 0px 0px;" cellpadding="0" cellspacing="0" align="left" border="0" bgcolor="" class="column column-0">
      <tbody>
        <tr>
          <td style="padding:0px;margin:0px;border-spacing:0;"><table class="wrapper" role="module" data-type="image" border="0" cellpadding="0" cellspacing="0" width="100%" style="table-layout: fixed;" data-muid="b61e00de-19e5-4f73-9ecc-b8ea4f872e5c">
    <tbody>
      <tr>
        
        <td style="padding:20px 15px 15px 15px; line-height:26px; text-align:inherit; background-color:#74bcd9;" height="100%" valign="top" bgcolor="#74bcd9" role="module-content"><div><div style="font-family: inherit; text-align: center"><span style="font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif; color: #ffffff; font-size: 24px"><strong>GCP Hackathon - Nisum</strong></span></div><div></div></div></td>
      </tr>
    </tbody>
  </table></td>
        </tr>
      </tbody>
    </table><table width="300" style="width:300px; border-spacing:0; border-collapse:collapse; margin:0px 0px 0px 0px;" cellpadding="0" cellspacing="0" align="left" border="0" bgcolor="" class="column column-1">
      <tbody>
        <tr>
          <td style="padding:0px;margin:0px;border-spacing:0;"><table class="module" role="module" data-type="spacer" border="0" cellpadding="0" cellspacing="0" width="100%" style="table-layout: fixed;" data-muid="1444ebb1-667b-4c9d-a9a5-5bf0e36fcce8">
    <tbody>
      <tr>
        <td style="padding:0px 0px 4px 0px;" role="module-content" bgcolor="">
        </td>
      </tr>
    </tbody>
  </table></td>
        </tr>
      </tbody>
    </table></td>
      </tr>
    </tbody>
  </table><table class="module" role="module" data-type="text" border="0" cellpadding="0" cellspacing="0" width="100%" style="table-layout: fixed;" data-muid="13d36c46-b515-4bdf-ad3c-edafb5c1c151" data-mc-module-version="2019-10-22">
    <tbody>
      <tr>
        <td style="padding:20px 15px 15px 15px; line-height:26px; text-align:inherit; background-color:#92a8d1;" height="100%" valign="top" bgcolor="#92a8d1" role="module-content"><div><div style="font-family: inherit; text-align: center"><span style="font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif; color: #ffffff; font-size: 24px"><strong>RELEASE &nbsp;ARTIFACT&nbsp;DEPLOYMENT&nbsp;REQUEST</strong></span></div><div></div></div></td>
      </tr>
    </tbody>
  </table><table border="0" cellpadding="0" cellspacing="0" align="center" width="100%" role="module" data-type="columns" style="padding:50px 20px 50px 20px;" bgcolor="#3172a3" data-distribution="1">
    <tbody>
      <tr role="module-content">
        <td height="100%" valign="top"><table width="460" style="width:460px; border-spacing:0; border-collapse:collapse; margin:0px 50px 0px 50px;" cellpadding="0" cellspacing="0" align="left" border="0" bgcolor="" class="column column-0">
      <tbody>
        <tr>
          <td style="padding:0px;margin:0px;border-spacing:0;"><table class="module" role="module" data-type="text" border="0" cellpadding="0" cellspacing="0" width="100%" style="table-layout: fixed;" data-muid="efe5a2c4-1b11-49e7-889d-856d80b40f63" data-mc-module-version="2019-10-22">
    <tbody>
      <tr>
        <td style="padding:40px 0px 30px 0px; line-height:5px; text-align:inherit; background-color:#74bcd9;" height="100%" valign="top" bgcolor="#74bcd9" role="module-content"><div><div style="font-family: inherit; text-align: center"><span style="font-size: 30px; color: #ffffff; font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif"><strong>REQUEST DETAILS</strong></span></div><div></div></div></td>
      </tr>
    </tbody>
  </table><table class="module" role="module" data-type="text" border="0" cellpadding="0" cellspacing="0" width="100%" style="table-layout: fixed;" data-muid="efe5a2c4-1b11-49e7-889d-856d80b40f63.2" data-mc-module-version="2019-10-22">
    <tbody>
      <tr>
        <td style="padding:50px 30px 30px 30px; line-height:28px; text-align:inherit; background-color:#ffffff;" height="100%" valign="top" bgcolor="#ffffff" role="module-content"><div>
<div style="font-family: inherit; text-align: inherit">
  <span style="font-size: 17px; font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif; color: #656565"><strong>Timestamp    = { timestamp } </strong></span>
  <br><span style="font-size: 17px; font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif; color: #656565"><strong>Intend ID        = "{ intendID }" </strong></span>
  <br><span style="font-size: 17px; font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif; color: #656565"><strong>Project Name     = { projectName } </strong></span>
  <br><span style="font-size: 17px; font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif; color: #656565"><strong>Artifact Name    = { artifactName } </strong></span>
  <br><span style="font-size: 17px; font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif; color: #656565"><strong>Artifact Version = { artifactVersion } </strong></span>
  <br><span style="font-size: 17px; font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif; color: #656565"><strong>Environment Name = { environment } </strong></span>
  <br><span style="font-size: 17px; font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif; color: #656565"><strong>Requester Email  = { requesterEmail } </strong></span>
  
  
</div><div></div></div></td>
      </tr>
    </tbody>
  </table><table border="0" cellpadding="0" cellspacing="0" class="module" data-role="module-button" data-type="button" role="module" style="table-layout:fixed;" width="100%" data-muid="d0bf6998-834d-4cc3-b775-8e43e7fcbf90">

    <tbody>
      <tr>
        <td align="left" bgcolor="#FFFFFF" class="outer-td" style="padding:0px 0px 0px 30px; background-color:#FFFFFF;">
          <table border="0" cellpadding="0" cellspacing="0" class="wrapper-mobile" style="text-align:center;">
            <tbody>
              <tr>
              <td align="center" bgcolor="#932A89" class="inner-td" style="border-radius:6px; font-size:16px; text-align:left; background-color:inherit;">
                <a href="https://docs.google.com/forms/d/e/1FAIpQLSdLoBKj2hZn2-hbCUroGDAbdrrytB1LE9GRiqlJ8uXT_2tKSA/viewform" style="background-color:#74bcd9; border:0px solid #333333; border-color:#333333; border-radius:0px; border-width:0px; color:#ffffff; display:inline-block; font-size:16px; font-weight:normal; letter-spacing:0px; line-height:normal; padding:15px 25px 15px 25px; text-align:center; text-decoration:none; border-style:solid; font-family:trebuchet ms,helvetica,sans-serif;" target="_blank"><strong>Click to Submit Artifact Approval Form<strong></a>
              </td>
              </tr>
            </tbody>
          </table>
        </td>
      </tr>
    </tbody>



    </table><table class="module" role="module" data-type="text" border="0" cellpadding="0" cellspacing="0" width="100%" style="table-layout: fixed;" data-muid="efe5a2c4-1b11-49e7-889d-856d80b40f63.1" data-mc-module-version="2019-10-22">
    <tbody>
      <tr>
        <td style="padding:40px 100px 50px 30px; line-height:26px; text-align:inherit; background-color:#FFFFFF;" height="100%" valign="top" bgcolor="#FFFFFF" role="module-content"><div><div style="font-family: inherit; text-align: inherit"><span style="font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif; font-size: 16px; color: #656565"><strong>Thanks!</strong></span></div>
<div style="font-family: inherit; text-align: inherit"><span style="font-family: &quot;trebuchet ms&quot;, helvetica, sans-serif; font-size: 16px; color: #656565"><strong>Team Geek Speak Hertz</strong></span></div><div></div></div></td>
      </tr>
    </tbody>
  </table></td>
        </tr>
      </tbody>
    </table></td>
      </tr>
    </tbody>
  </table><table border="0" cellpadding="0" cellspacing="0" align="center" width="100%" role="module" data-type="columns" style="padding:0px 20px 0px 20px;" bgcolor="#92a8d1" data-distribution="1">




  </table><table border="0" cellpadding="0" cellspacing="0" align="center" width="100%" role="module" data-type="columns" style="padding:40px 0px 1px 0px;" bgcolor="#F0F0F0" data-distribution="1">
    <tbody>
      <tr role="module-content">
        <td height="100%" valign="top"><table width="580" style="width:580px; border-spacing:0; border-collapse:collapse; margin:0px 10px 0px 10px;" cellpadding="0" cellspacing="0" align="left" border="0" bgcolor="" class="column column-0">
      <tbody>
        <tr>
          <td style="padding:0px;margin:0px;border-spacing:0;"><table class="module" role="module" data-type="social" align="center" border="0" cellpadding="0" cellspacing="0" width="100%" style="table-layout: fixed;" data-muid="da66730a-c885-4e7b-bda0-4df5c4f2ce23">
    <tbody>
      <tr>
        <td valign="top" style="padding:0px 0px 0px 0px; font-size:6px; line-height:10px;" align="center">
          <table align="center" style="-webkit-margin-start:auto;-webkit-margin-end:auto;">
            <tbody><tr align="center"><td style="padding: 0px 5px;" class="social-icon-column">
      <a role="social-icon-link" href="https://www.facebook.com" target="_blank" alt="Facebook" title="Facebook" style="display:inline-block; background-color:#9D9D9D; height:21px; width:21px;">
        <img role="social-icon" alt="Facebook" title="Facebook" src="https://mc.sendgrid.com/assets/social/white/facebook.png" style="height:21px; width:21px;" height="21" width="21">
      </a>
    </td><td style="padding: 0px 5px;" class="social-icon-column">
      <a role="social-icon-link" href="https://twitter.com" target="_blank" alt="Twitter" title="Twitter" style="display:inline-block; background-color:#9D9D9D; height:21px; width:21px;">
        <img role="social-icon" alt="Twitter" title="Twitter" src="https://mc.sendgrid.com/assets/social/white/twitter.png" style="height:21px; width:21px;" height="21" width="21">
      </a>
    </td><td style="padding: 0px 5px;" class="social-icon-column">
      <a role="social-icon-link" href="https://www.instagram.com" target="_blank" alt="Instagram" title="Instagram" style="display:inline-block; background-color:#9D9D9D; height:21px; width:21px;">
        <img role="social-icon" alt="Instagram" title="Instagram" src="https://mc.sendgrid.com/assets/social/white/instagram.png" style="height:21px; width:21px;" height="21" width="21">
      </a>
    </td><td style="padding: 0px 5px;" class="social-icon-column">
      <a role="social-icon-link" href="https://www.pinterest.com" target="_blank" alt="Pinterest" title="Pinterest" style="display:inline-block; background-color:#9D9D9D; height:21px; width:21px;">
        <img role="social-icon" alt="Pinterest" title="Pinterest" src="https://mc.sendgrid.com/assets/social/white/pinterest.png" style="height:21px; width:21px;" height="21" width="21">
      </a>
    </td><td style="padding: 0px 5px;" class="social-icon-column">
      <a role="social-icon-link" href="https://www.linkedin.com/company/nisum-technologies/" target="_blank" alt="LinkedIn" title="LinkedIn" style="display:inline-block; background-color:#9D9D9D; height:21px; width:21px;">
        <img role="social-icon" alt="LinkedIn" title="LinkedIn" src="https://mc.sendgrid.com/assets/social/white/linkedin.png" style="height:21px; width:21px;" height="21" width="21">
      </a>
    </td></tr></tbody>
          </table>
        </td>
      </tr>
    </tbody>
  </table><div data-role="module-unsubscribe" class="module" role="module" data-type="unsubscribe" style="color:#656565; font-size:12px; line-height:22px; padding:16px 16px 5px 16px; text-align:Center;" data-muid="4e838cf3-9892-4a6d-94d6-170e474d21e5"><div class="Unsubscribe--addressLine"><p class="Unsubscribe--senderName" style="font-family:trebuchet ms,helvetica,sans-serif; font-size:12px; line-height:22px;">Geek Speak Hertz</p><p style="font-family:trebuchet ms,helvetica,sans-serif; font-size:12px; line-height:22px;"><span class="Unsubscribe--senderAddress">Nisum Pakistan</span>, <span class="Unsubscribe--senderCity">Karachi</span>, <span class="Unsubscribe--senderState">Sindh</span> <span class="Unsubscribe--senderZip">75500</span></p></div><p style="font-family:trebuchet ms,helvetica,sans-serif; font-size:12px; line-height:22px;"><a class="Unsubscribe--unsubscribeLink" href="" target="_blank" style="color:#9D9D9D;"></a></p></div><table border="0" cellpadding="0" cellspacing="0" class="module" data-role="module-button" data-type="button" role="module" style="table-layout:fixed;" width="100%" data-muid="63b00288-52a6-4caa-9337-9e7da43b1a6f">
      <tbody>
        <tr>
          <td align="center" bgcolor="" class="outer-td" style="padding:20px 0px 20px 0px;">
            <table border="0" cellpadding="0" cellspacing="0" class="wrapper-mobile" style="text-align:center;">
              <tbody>
                <tr>
                <td align="center" bgcolor="#F5F8FD" class="inner-td" style="border-radius:6px; font-size:16px; text-align:center; background-color:inherit;">
                  <a href="https://sendgrid.com/" style="background-color:#F5F8FD; border:1px solid #F5F8FD; border-color:#F5F8FD; border-radius:25px; border-width:1px; color:#A8B9D5; display:inline-block; font-size:10px; font-weight:normal; letter-spacing:0px; line-height:normal; padding:5px 18px 5px 18px; text-align:center; text-decoration:none; border-style:solid; font-family:helvetica,sans-serif;" target="_blank">♥ POWERED BY GEEK SPEAK HERTZ</a>
                </td>
                </tr>
              </tbody>
            </table>
          </td>
        </tr>
      </tbody>
    </table></td>
        </tr>
      </tbody>
    </table></td>
      </tr>
    </tbody>
  </table></td>
                                      </tr>
                                    </table>
                                    <!--[if mso]>
                                  </td>
                                </tr>
                              </table>
                            </center>
                            <![endif]-->
                          </td>
                        </tr>
                      </table>
                    </td>
                  </tr>
                </table>
              </td>
            </tr>
          </table>
        </div>
      </center>
    </body>
  </html>
"""

    if "environment" in message_json:
      print("Environment Key exist in JSON data")

      if message_json["environment"] == "QA":
        message = Mail(
          from_email='asad.r.hussain@gmail.com',
          to_emails=['asad.r.hussain@gmail.com','niks3595@gmail.com'],
          subject='GCP Hackathon - Request Artifact Deployment',
          html_content= HtmlContent(html_text))

      elif message_json["environment"] == "DEV":
        message = Mail(
          from_email='asad.r.hussain@gmail.com',
          to_emails=['asad.r.hussain@gmail.com','t3hami@gmail.com'],
          subject='GCP Hackathon - Request Artifact Deployment',
          html_content= HtmlContent(html_text))

      elif message_json["environment"] == "PERF":
        message = Mail(
          from_email='asad.r.hussain@gmail.com',
          to_emails=['asad.r.hussain@gmail.com'],
          subject='GCP Hackathon - Request Artifact Deployment',
          html_content= HtmlContent(html_text))

      elif message_json["environment"] == "PROD":
        message = Mail(
          from_email='asad.r.hussain@gmail.com',
          to_emails=['asad.r.hussain@gmail.com','t3hami@gmail.com','niks3595@gmail.com'],
          subject='GCP Hackathon - Request Artifact Deployment',
          html_content= HtmlContent(html_text))

    else:
      print("Environment Not Found")
    
    try:
        sg = SendGridAPIClient('<ADD SENDGRID APII KEY')    #Change API KEY FOR SENDGRID
        response = sg.send(message)
        print(response.status_code)
        print(response.body)
        print(response.headers)
    except Exception as e:
        print(e)

    print(pubsub_message)
